@@ -1,4 +1,3 @@
-#
 # John Pritchard
 #
 # Developed from esotk_fringe_obj_mask.py by Mark Neeser
@@ -26,10 +25,7 @@ try:
     import wx
     from wx import xrc
     import numpy
-    try :
-        from astropy.io import fits as pyfits
-    except:
-        import pyfits
+    from astropy.io import fits as pyfits
     import reflex
     import pipeline_product
     import pipeline_display
@@ -221,7 +217,7 @@ try:
                         FPS = self.dataPlotManager.sci_rbnspectra_extr.extractedscience.all_hdu[1].data['FPS'][int(event.xdata-0.5)]
                         SSN = self.dataPlotManager.sci_rbnspectra_extr.extractedscience.all_hdu[1].data['SSN'][int(event.xdata-0.5)]
                         OBJECT_SNR = self.dataPlotManager.sci_rbnspectra_extr.SNRarr[int(event.xdata-0.5)]
-                        str=" %s, S/N = %5.2f [FPS/SSN=%d/%d, col=%d]" %(OBJECT,OBJECT_SNR,FPS,SSN,int(event.xdata+0.5))
+                        str=" %s, S/N = %5.2f [FPS/SSN=%d/%d, col=%d]" %(OBJECT.strip(),OBJECT_SNR,FPS,SSN,int(event.xdata+0.5))
                 self.statusBar.SetStatusText(event.inaxes.format_coord(event.xdata,
                                                                    event.ydata)+str)
             else:
@@ -269,7 +265,7 @@ try:
 
 
 
-    class PipelineInteractiveApp(reflex_interactive_app.PipelineInteractiveApp):
+    class PipelineInteractiveApp(reflex_interactive_app.PipelineInteractiveApp, object):
         """
         This class overrides the showGUI method to bind the event handlers for
         the customised GUI layout provided by the esotk_giraf_gui.xrc file.
@@ -360,7 +356,7 @@ def runInteractiveApp(dataManagerClass):
         # Note: we have to print this message after interactive_app is created
         # or else this message will not be shown in the Reflex error message.
         sys.stderr.write("Error importing one of the modules wx, reflex," \
-                         " numpy, pyfits, pylab or matplotlib.\n")
+                         " numpy, astropy.io/pyfits, pylab or matplotlib.\n")
         interactive_app.setEnableGUI(False)
 
     # Open the interactive window if enabled.
