@@ -35,7 +35,7 @@ try:
         outlist=list()
         for file in files:
             #select a file category:
-            if file.category == 'SCIENCE' or file.category == 'STD' :
+            if file.category in ['SCIENCE', 'STD' ] :
 
                 purpose=file.purposes[0]
                 try: 
@@ -85,23 +85,25 @@ try:
                 HDU['CRMASK'].header['BZERO']=0.
                 HDU[0].header.append(("NFILES", 1, "number of input files"))
                 HDU[0].header.append(("CMETHOD", "ASTROSCRAPPY", "method for bad pixel cleaning"))
-                HDU[0].header.append(('HIERARCH ESO ASCRAP',True,'AstroScrappy Cosmic Ray cleaning applied'))
+                HDU[0].header.append(("HIERARCH ESO DRS CMETHOD", "ASTROSCRAPPY", "method for bad pixel cleaning"))
+                HDU[0].header.append(('HIERARCH ESO DRS ASCRAP',True,'AstroScrappy Cosmic Ray cleaning applied'))
                 if purpose in masterbiases :
-                    HDU[0].header.append(('HIERARCH ESO ASCRAP BIASSUB',True,'MASTER_BIAS subtracted?'))
-                    HDU[0].header.append(('HIERARCH ESO ASCRAP BIAS NAME',os.path.basename(masterbiases[purpose].name)[0:80-len('HIERARCH ESO ASCRAP BIAS NAME')-5],'MASTER BIAS used'))
-                HDU[0].header.append(('HIERARCH ESO ASCRAP RON',HDU[0].header['HIERARCH ESO DET OUT1 RON'],'Readout noise'))
-                HDU[0].header.append(('HIERARCH ESO ASCRAP GAIN',HDU[0].header['HIERARCH ESO DET OUT1 CONAD'],'Gain'))
+                    HDU[0].header.append(('HIERARCH ESO DRS ASCRAP BIASSUB',True,'MASTER_BIAS subtracted?'))
+                    HDU[0].header.append(('HIERARCH ESO DRS ASCRAP BIAS NAME',os.path.basename(masterbiases[purpose].name)[0:80-len('HIERARCH ESO ASCRAP BIAS NAME')-5],'MASTER BIAS used'))
+                HDU[0].header.append(('HIERARCH ESO DRS ASCRAP RON',HDU[0].header['HIERARCH ESO DET OUT1 RON'],'Readout noise'))
+                HDU[0].header.append(('HIERARCH ESO DRS ASCRAP GAIN',HDU[0].header['HIERARCH ESO DET OUT1 CONAD'],'Gain'))
 
                 # define file names:
                 clean_file= parameters["--products-dir"] + "/" + \
                        file.name.replace(".fits", "_AS_clean.fits").split("/")[-1]
-                file.name= clean_file
+                file.name=clean_file
                 try:
-                    HDU.writeto(clean_file, overwrite=True)
+                    HDU.writeto(clean_file, outpur_verify='silentfix+ignore', overwrite=True)
                 except:
-                    HDU.writeto(clean_file, clobber=True)
+                    HDU.writeto(clean_file, output_verify='silentfix+ignore', clobber=True)
                 HDU.close()
-                bHDU.close()
+                if purpose in masterbiases :
+                    bHDU.close()
 
                 # update purpose
                 outlist.append((reflex.FitsFile(file.name,file.category,None,[unicode("AS_crclean/")+file.purposes[0]])))
@@ -109,13 +111,16 @@ try:
         #send output to EsoReflex:
         newsof = reflex.SetOfFiles(inputs.in_sof.datasetName,outlist)
         outputs.out_sof = newsof
-        for file in outlist:
-            print("output:", file.name, file.category, file.purposes)
+        #for file in outlist:
+            #print("output:", file.name, file.category, file.purposes)
 
 
 except ImportError:
     import_sucess = False
-    print "Error importing one or more of the modules pyfits, astroscrappy"
+    print "Error importing one or more of the modules astropy.io/pyfits, astroscrappy"
+
+except :
+    raise
 
 if __name__ == '__main__':
   
@@ -127,15 +132,17 @@ if __name__ == '__main__':
 
     #Define ports:
     parser.add_option("-i", "--in_sof", dest="in_sof")
+    #parser.add_option("-e", "--enable", dest="enable", default='false')
     parser.add_output("-o", "--out_sof", dest="out_sof")
 
     inputs  = parser.get_inputs()
     outputs = parser.get_outputs()
 
     #Check if import failed or not
-    if import_sucess :
+    if import_sucess : #and inputs.enable == "true" :
         astroscrappy_multi()
     else :
+        # write out an empty sof
         outputs.out_sof = reflex.SetOfFiles(inputs.in_sof.datasetName,list())
 
     parser.write_outputs()
