@@ -54,24 +54,30 @@ try:
 
                     # update header:
                     for i in range(ifile):
-                        filename= (scifiles[i].name).split("/")[-1]
+                        filename=(scifiles[i].name).split("/")[-1]
                         firstraw[0].header.append(("IFILE"+str(i), filename, "input file for median"))
                     firstraw[0].header.append(("NFILES", ifile+1, "number of input files"))
                     if ifile == len(scifiles)-1:
                         firstraw[0].header.append(("CMETHOD", "MEDIAN", "method for bad pixel cleaning"))
+                        firstraw[0].header.append(("HIERARCH ESO PRO CMETHOD", "MEDIAN", "method for bad pixel cleaning"))
+                        firstraw[0].header.append(("HIERARCH ESO DRS CMETHOD", "MEDIAN", "method for bad pixel cleaning"))
                     else:
                         firstraw[0].header.append(("CMETHOD", "SUBMED_%d" %(ifile+1), "method for bad pixel cleaning"))
+                        firstraw[0].header.append(("HIERARCH ESO PRO CMETHOD", "SUBMED_%d" %(ifile+1), "method for bad pixel cleaning"))
+                        firstraw[0].header.append(("HIERARCH ESO DRS CMETHOD", "SUBMED_%d" %(ifile+1), "method for bad pixel cleaning"))
 
                     # write fits file:
                     try:
-                        firstraw.writeto(median_file, checksum=True, overwrite=True)
+                        firstraw.writeto(median_file, output_verify='silentfix+ignore', checksum=True, overwrite=True)
                     except:
-                        firstraw.writeto(median_file, checksum=True, clobber=True)
+                        firstraw.writeto(median_file, output_verify='silentfix+ignore', checksum=True, clobber=True)
                     firstraw.close()
 
                 # And write out a copy of the individual raw files
                 raw[0].header.append(("NFILES", 1, "number of input files"))
                 raw[0].header.append(("CMETHOD", "NONE", "method for bad pixel cleaning"))
+                raw[0].header.append(("HIERARCH ESO PRO CMETHOD", "NONE", "method for bad pixel cleaning"))
+                raw[0].header.append(("HIERARCH ESO DRS CMETHOD", "NONE", "method for bad pixel cleaning"))
                 try:
                     raw.writeto(parameters["--products-dir"] + "/" + os.path.basename(file.name), overwrite=True)
                 except:
@@ -85,8 +91,8 @@ try:
                 # now add the new median files:
                 for imed, median_file in enumerate(median_files):
                     outlist.append((reflex.FitsFile(median_file,scifiles[0].category,None,[unicode("med"+str(imed+3)+"/") + oldpurpose])))
-                for file in outlist:
-                    print("output:", file.name, file.category, file.purposes)
+                #for file in outlist:
+                #    print("output:", file.name, file.category, file.purposes)
 
         #send output to EsoReflex:
         newsof = reflex.SetOfFiles(inputs.in_sof.datasetName,outlist)
